@@ -28,9 +28,21 @@ def authorizer(claims: dict) -> bool:
 
     for action, resource in claims.items():
         satisfied = False
-        for res in user.permissions.match(action=action):
-            if res.name == resource:
-                satisfied = True
+        user.permissions.filters.clear()
+
+        if isinstance(resource, str):
+            for res in user.permissions.match(action=action):
+                if res.name == resource:
+                    satisfied = True
+
+        elif isinstance(resource, list):
+            found_permissions = list()
+
+            for res in user.permissions.match(action=action):
+                if res.name in resource:
+                    found_permissions.append(res)
+
+            satisfied = len(found_permissions) == len(resource)
 
         if not satisfied:
             return False
